Problem Index

# Rembrandt's Picture

A logic problem by Brandon Bennett

Your problem is to use propositional logic to represent the following example of reasoning, and use the Prover9 theorem prover to prove that the reasoning is valid.

You should use the following template file to create your Prover9 encoding of the problem:
`rembrandt.p9`

Marks: There are two marks for each sentence, making a total of 8 marks.

## Problem Statement

A1: Either the picture is valuable or it is a fake.

A2: If it is valuable it is by Rembrandt.

A3: If it is a fake there will be a police investigation.

Goal: Either the picture is by Rembrandt or there will be a police investigation.

### Non-Logical Vocabulary

Propositional Constants: `PictureIsValuable`, `PictureIsFake`, `PictureByRembrandt`, `PoliceInvestigation`